Crate silver_platter

Crate silver_platter 

Silver-Platter

Silver-Platter makes it possible to contribute automatable changes to source code in a version control system (codemods).

It automatically creates a local checkout of a remote repository, makes user-specified changes, publishes those changes on the remote hosting site and then creates a pull request.

In addition to that, it can also perform basic maintenance on branches that have been proposed for merging - such as restarting them if they have conflicts due to upstream changes.

Modules

batch
Batch management.
candidates
Candidates for packages.
checks
Check if the package should be uploaded
codemod
Codemod
debian
Utility functions for working with Debian packages.
probers
Selection of probers
proposal
Merge proposal related functions
publish
Publishing changes
recipe
Recipes
run
Run the codemod script and publish the changes as a merge proposal.
utils
Utility functions for working with branches.
vcs
Version control system (VCS) support.
workspace
Workspace for preparing changes for publication

Structs

Forge
Represents a code forge (hosting service) like GitHub, GitLab, etc.
GenericBranch
A generic branch that can represent any type of branch.
MergeProposal
A merge proposal (pull request) on a code hosting service.
RevisionId
Represents a unique identifier for a revision in a version control system.
Transport
A transport represents a way to access content in a branch.

Enums

CommitPending
Policy on whether to commit pending changes
Mode
Publish mode

Constants

VERSION
The version of the library

Traits

Branch
Trait representing a branch in a version control system.
CodemodResult
The result of a codemod
ControlDir
Trait for control directories.
Prober
Trait for probers that can detect control directories.
WorkingTree
Trait representing a working tree in a version control system.

Functions

derived_branch_name
Returns the branch name derived from a script name