Batch

Struct Batch 

pub struct Batch {
    pub version: u8,
    pub recipe: Recipe,
    pub name: String,
    pub work: HashMap<String, Entry>,
    pub basepath: PathBuf,
}
Batch

Fields

version: u8

Format version

recipe: Recipe

Recipe

name: String

Batch name

work: HashMap<String, Entry>

Work to be done in this batch.

basepath: PathBuf

Basepath for the batch

Implementations

Source

impl Batch

pub fn from_recipe<'a>( recipe: &Recipe, candidates: impl Iterator<Item = &'a Candidate>, directory: &Path, extra_env: Option<HashMap<String, String>>, ) -> Result<Batch, Error>

Create a batch from a recipe and a set of candidates.

pub fn get(&self, name: &str) -> Option<&Entry>

Get reference to a batch entry.

pub fn get_mut(&mut self, name: &str) -> Option<&mut Entry>

Get a mutable reference to a batch entry.

pub fn status(&self) -> HashMap<&str, Status>

Returen the status of all work in the batch.

pub fn remove(&mut self, name: &str) -> Result<(), Error>

Remove work from the batch.