PrepareUploadError

Enum PrepareUploadError 

pub enum PrepareUploadError {
Show 17 variants GbpDchFailed, NoUnuploadedChanges(Version), LastUploadMoreRecent(Version, Version), LastReleaseRevisionNotFound(String, Version), NoUnreleasedChanges(Version), GeneratedChangelogFile, NoValidGpgSignature(RevisionId, VerificationResult), Rejected(RevisionRejected), BuildFailed, MissingUpstreamTarball(String, String), PackageVersionNotPresent(String, String), MissingChangelog, ChangelogParseError(String), BrzError(Error), DebianError(Error), MissingNestedTree(PathBuf), SignError(SignError),
}
Errors that can occur when preparing a package for upload.

Variants



GbpDchFailed

Failed to run gbp dch



NoUnuploadedChanges(Version)

No unuploaded changes since the last upload



LastUploadMoreRecent(Version, Version)

The last upload was more recent than the previous upload



LastReleaseRevisionNotFound(String, Version)

The last release revision was not found



NoUnreleasedChanges(Version)

No unreleased changes



GeneratedChangelogFile

Generated changelog file



NoValidGpgSignature(RevisionId, VerificationResult)

No valid GPG signature



Rejected(RevisionRejected)

Revision rejected



BuildFailed

Build failed



MissingUpstreamTarball(String, String)

Missing upstream tarball



PackageVersionNotPresent(String, String)

Package version not present



MissingChangelog

Missing changelog



ChangelogParseError(String)

Changelog parse error



BrzError(Error)

Breezy error



DebianError(Error)

Debian error



MissingNestedTree(PathBuf)

There is a missing nested tree



SignError(SignError)

Sign error