pub enum Mode {
Push,
Propose,
AttemptPush,
PushDerived,
Bts,
}Expand description
Publish mode
Variants
Push
Push to the target branch
Propose
Propose a merge
AttemptPush
Attempt to push to the target branch, falling back to propose if necessary
PushDerived
Push to a branch derived from the script name
Bts
Bug tracking system