pub struct RevisionId(/* private fields */);Expand description
Represents a unique identifier for a revision in a version control system.
RevisionId is typically a string in UTF-8 encoding, but is stored as bytes to efficiently handle all possible revision formats across different VCS systems.
Implementations
Sourceimpl RevisionId
impl RevisionId
Sourcepub fn is_null(&self) -> bool
pub fn is_null(&self) -> bool
Check if this revision ID is the null revision.
Returns
true if this is the null revision, false otherwise
Sourcepub fn is_reserved(&self) -> bool
pub fn is_reserved(&self) -> bool
Check if this revision ID is a reserved revision.
Reserved revision IDs start with a colon character.
Returns
true if this is a reserved revision, false otherwise
Sourcepub fn null() -> RevisionId
pub fn null() -> RevisionId