pub struct Transport(/* private fields */);Expand description
A transport represents a way to access content in a branch.
Implementations
Sourceimpl Transport
impl Transport
Sourcepub fn local_abspath(&self, path: &Path) -> Result<PathBuf, Error>
pub fn local_abspath(&self, path: &Path) -> Result<PathBuf, Error>
Get the local absolute path for a path within this transport.
Sourcepub fn ensure_base(&self) -> Result<(), Error>
pub fn ensure_base(&self) -> Result<(), Error>
Ensure the base directory exists.
Sourcepub fn create_prefix(&self) -> Result<(), Error>
pub fn create_prefix(&self) -> Result<(), Error>
Create all the directories leading up to the final path component.