pub struct TempSprout {
pub workingtree: GenericWorkingTree,
pub tempdir: Option<TempDir>,
}Expand description
A temporary sprout of a branch.
Fields
workingtree: GenericWorkingTreeThe working tree of the sprout.
tempdir: Option<TempDir>The temporary directory that the sprout is in.
Implementations
Sourceimpl TempSprout
impl TempSprout
Sourcepub fn new(
branch: &dyn PyBranch,
additional_colocated_branches: Option<HashMap<String, String>>,
) -> Result<Self, BrzError>
pub fn new( branch: &dyn PyBranch, additional_colocated_branches: Option<HashMap<String, String>>, ) -> Result<Self, BrzError>
Create a temporary sprout of a branch.
Sourcepub fn new_in(
branch: &dyn PyBranch,
additional_colocated_branches: Option<HashMap<String, String>>,
dir: &Path,
) -> Result<Self, BrzError>
pub fn new_in( branch: &dyn PyBranch, additional_colocated_branches: Option<HashMap<String, String>>, dir: &Path, ) -> Result<Self, BrzError>
Create a temporary sprout of a branch in a specific directory.
Sourcepub fn new_in_path(
branch: &dyn PyBranch,
additional_colocated_branches: Option<HashMap<String, String>>,
path: &Path,
) -> Result<Self, BrzError>
pub fn new_in_path( branch: &dyn PyBranch, additional_colocated_branches: Option<HashMap<String, String>>, path: &Path, ) -> Result<Self, BrzError>
Create a temporary sprout of a branch with a specific path.
Sourcepub fn tree(&self) -> &dyn WorkingTree
pub fn tree(&self) -> &dyn WorkingTree
Return the tree of the sprout.