pub struct Forge(/* private fields */);Expand description
Represents a code forge (hosting service) like GitHub, GitLab, etc.
Implementations
Sourceimpl Forge
impl Forge
Sourcepub fn get_proposal_by_url(&self, url: &Url) -> Result<MergeProposal, Error>
pub fn get_proposal_by_url(&self, url: &Url) -> Result<MergeProposal, Error>
Retrieves a merge proposal by its URL.
Sourcepub fn get_web_url(
&self,
branch: &(dyn PyBranch + 'static),
) -> Result<Url, Error>
pub fn get_web_url( &self, branch: &(dyn PyBranch + 'static), ) -> Result<Url, Error>
Returns the web URL for a given branch on this forge.
Sourcepub fn forge_kind(&self) -> String
pub fn forge_kind(&self) -> String
Returns the kind of forge (e.g., GitHub, GitLab).
Sourcepub fn forge_name(&self) -> String
pub fn forge_name(&self) -> String
Returns the name of the forge.
Sourcepub fn merge_proposal_description_format(&self) -> String
pub fn merge_proposal_description_format(&self) -> String
Returns the format used for merge proposal descriptions on this forge.
Sourcepub fn supports_merge_proposal_commit_message(&self) -> bool
pub fn supports_merge_proposal_commit_message(&self) -> bool
Checks if this forge supports setting commit messages for merge proposals.
Sourcepub fn supports_merge_proposal_title(&self) -> bool
pub fn supports_merge_proposal_title(&self) -> bool
Checks if this forge supports setting titles for merge proposals.
Sourcepub fn supports_merge_proposal_labels(&self) -> bool
pub fn supports_merge_proposal_labels(&self) -> bool
Checks if this forge supports adding labels to merge proposals.
Sourcepub fn get_proposer(
&self,
from_branch: &(dyn PyBranch + 'static),
to_branch: &(dyn PyBranch + 'static),
) -> Result<ProposalBuilder, Error>
pub fn get_proposer( &self, from_branch: &(dyn PyBranch + 'static), to_branch: &(dyn PyBranch + 'static), ) -> Result<ProposalBuilder, Error>
Creates a proposal builder for a merge proposal from one branch to another.
Sourcepub fn iter_my_proposals(
&self,
status: Option<MergeProposalStatus>,
author: Option<String>,
) -> Result<impl Iterator<Item = MergeProposal>, Error>
pub fn iter_my_proposals( &self, status: Option<MergeProposalStatus>, author: Option<String>, ) -> Result<impl Iterator<Item = MergeProposal>, Error>
Returns an iterator over merge proposals owned by the current user.
Sourcepub fn get_derived_branch(
&self,
main_branch: &(dyn PyBranch + 'static),
name: &str,
owner: Option<&str>,
preferred_schemes: Option<&[&str]>,
) -> Result<Box<dyn Branch>, Error>
pub fn get_derived_branch( &self, main_branch: &(dyn PyBranch + 'static), name: &str, owner: Option<&str>, preferred_schemes: Option<&[&str]>, ) -> Result<Box<dyn Branch>, Error>
Gets a branch derived from a main branch with the given name and optional owner.
Sourcepub fn iter_proposals(
&self,
source_branch: &(dyn PyBranch + 'static),
target_branch: &(dyn PyBranch + 'static),
status: MergeProposalStatus,
) -> Result<impl Iterator<Item = MergeProposal>, Error>
pub fn iter_proposals( &self, source_branch: &(dyn PyBranch + 'static), target_branch: &(dyn PyBranch + 'static), status: MergeProposalStatus, ) -> Result<impl Iterator<Item = MergeProposal>, Error>
Returns an iterator over merge proposals from one branch to another.
Sourcepub fn publish_derived(
&self,
local_branch: &(dyn PyBranch + 'static),
base_branch: &(dyn PyBranch + 'static),
name: &str,
overwrite: Option<bool>,
owner: Option<&str>,
revision_id: Option<&RevisionId>,
tag_selector: Option<Box<dyn Fn(String) -> bool>>,
) -> Result<(Box<dyn Branch>, Url), Error>
pub fn publish_derived( &self, local_branch: &(dyn PyBranch + 'static), base_branch: &(dyn PyBranch + 'static), name: &str, overwrite: Option<bool>, owner: Option<&str>, revision_id: Option<&RevisionId>, tag_selector: Option<Box<dyn Fn(String) -> bool>>, ) -> Result<(Box<dyn Branch>, Url), Error>
Publishes a derived branch and returns the branch and its URL.
Sourcepub fn get_push_url(&self, branch: &(dyn PyBranch + 'static)) -> Url
pub fn get_push_url(&self, branch: &(dyn PyBranch + 'static)) -> Url
Returns the URL for pushing to a branch on this forge.