GenericBranch

Struct GenericBranch 

pub struct GenericBranch(/* private fields */);
A generic branch that can represent any type of branch.

This struct wraps a Python branch object and provides access to it through the Branch trait.