pub struct MergeProposal(/* private fields */);Expand description
A merge proposal (pull request) on a code hosting service.
Implementations
Sourceimpl MergeProposal
impl MergeProposal
Sourcepub fn from_url(url: &Url) -> Result<MergeProposal, Error>
pub fn from_url(url: &Url) -> Result<MergeProposal, Error>
Create a merge proposal reference from a URL.
Sourcepub fn is_closed(&self) -> Result<bool, Error>
pub fn is_closed(&self) -> Result<bool, Error>
Checks if the merge proposal has been closed without being merged.
Sourcepub fn get_title(&self) -> Result<Option<String>, Error>
pub fn get_title(&self) -> Result<Option<String>, Error>
Retrieves the title of the merge proposal.
Sourcepub fn set_title(&self, title: Option<&str>) -> Result<(), Error>
pub fn set_title(&self, title: Option<&str>) -> Result<(), Error>
Sets the title of the merge proposal.
Sourcepub fn get_commit_message(&self) -> Result<Option<String>, Error>
pub fn get_commit_message(&self) -> Result<Option<String>, Error>
Retrieves the commit message associated with the merge proposal.
Sourcepub fn set_commit_message(
&self,
commit_message: Option<&str>,
) -> Result<(), Error>
pub fn set_commit_message( &self, commit_message: Option<&str>, ) -> Result<(), Error>
Sets the commit message for the merge proposal.
Sourcepub fn get_target_branch_url(&self) -> Result<Option<Url>, Error>
pub fn get_target_branch_url(&self) -> Result<Option<Url>, Error>
Returns the URL of the target branch for this merge proposal.
Sourcepub fn get_source_branch_url(&self) -> Result<Option<Url>, Error>
pub fn get_source_branch_url(&self) -> Result<Option<Url>, Error>
Returns the URL of the source branch for this merge proposal.
Sourcepub fn get_description(&self) -> Result<Option<String>, Error>
pub fn get_description(&self) -> Result<Option<String>, Error>
Retrieves the description of the merge proposal.
Sourcepub fn set_description(&self, description: Option<&str>) -> Result<(), Error>
pub fn set_description(&self, description: Option<&str>) -> Result<(), Error>
Sets the description of the merge proposal.
Sourcepub fn can_be_merged(&self) -> Result<bool, Error>
pub fn can_be_merged(&self) -> Result<bool, Error>
Checks if the merge proposal can currently be merged.
Sourcepub fn supports_auto_merge(&self) -> bool
pub fn supports_auto_merge(&self) -> bool
Checks if the merge proposal supports automatic merging.
Sourcepub fn merge(&self, auto: bool) -> Result<(), Error>
pub fn merge(&self, auto: bool) -> Result<(), Error>
Merges the merge proposal, optionally using automatic merge.
The auto parameter determines whether to use automatic merging.
Sourcepub fn get_web_url(&self) -> Result<Url, Error>
pub fn get_web_url(&self) -> Result<Url, Error>
Returns the web URL for viewing the merge proposal in a browser.