Trait Prober
Source pub trait Prober: Debug {
// Required methods
fn probe_transport(&self, transport: &Transport) -> Result<bool, Error>;
fn probe(&self, url: &Url) -> Result<bool, Error>;
}
Trait for probers that can detect control directories.
This trait defines the interface for probers, which are used to detect
the presence of control directories (like .git or .bzr) in a location.
Check if a control directory exists at the location specified by a transport.
Parameters
transport - The transport to probe.
Returns
Ok(true) if a control directory exists, Ok(false) if not, or an error
if the probe could not be completed.
Check if a control directory exists at the specified URL.
Parameters
Returns
Ok(true) if a control directory exists, Ok(false) if not, or an error
if the probe could not be completed.